pub type ProviderCostEstimator = fn(&str, &ProviderMetering) -> Option<ProviderCostEstimate>;Expand description
Application callback used only for legacy receipts that did not store a cost.
pub type ProviderCostEstimator = fn(&str, &ProviderMetering) -> Option<ProviderCostEstimate>;Application callback used only for legacy receipts that did not store a cost.